<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ja">
<context>
    <name>RemoveLayer</name>
    <message>
        <source>&amp;Remove Layer</source>
        <translation type="vanished">&amp;R 画層削除</translation>
    </message>
    <message>
        <location filename="../RemoveLayerInit.js" line="+2"/>
        <source>&amp;Delete Layer</source>
        <translation>レイヤーの削除</translation>
    </message>
</context>
</TS>
